==> haskell-tasty-hslua-1.1.1-132.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hslua
version:              1.1.1
visibility:           public
id:                   tasty-hslua-1.1.1-Cxwo3g1LYdrEZnaBXyoSlY
key:                  tasty-hslua-1.1.1-Cxwo3g1LYdrEZnaBXyoSlY
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Tasty helpers to test HsLua.
description:
    Various tasty helpers and utilities to test HsLua
    oparations. Built on top of tasty-hunit.

category:             Foreign
abi:                  f85b1e92eeb0fa750d1526bb4d4ee2b6
exposed:              True
exposed-modules:      Test.Tasty.HsLua
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hslua
hs-libraries:         HStasty-hslua-1.1.1-Cxwo3g1LYdrEZnaBXyoSlY
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP
    tasty-hunit-0.10.2-2LR7aB9N8B7BXZbrMOVMFb

haddock-interfaces:   /usr/share/doc/haskell-tasty-hslua/html/tasty-hslua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hslua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hslua-1.1.1-133-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hslua
version:              1.1.1
visibility:           public
id:                   tasty-hslua-1.1.1-5H7etHLdV98DrfWWfgyWjB
key:                  tasty-hslua-1.1.1-5H7etHLdV98DrfWWfgyWjB
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Tasty helpers to test HsLua.
description:
    Various tasty helpers and utilities to test HsLua
    oparations. Built on top of tasty-hunit.

category:             Foreign
abi:                  46bd33894caf6e8b94c67dbfe7f84015
exposed:              True
exposed-modules:      Test.Tasty.HsLua
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hslua-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hslua
hs-libraries:         HStasty-hslua-1.1.1-5H7etHLdV98DrfWWfgyWjB
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB
    tasty-hunit-0.10.2-96pg6B929I9E8nnywjEniv

haddock-interfaces:   /usr/share/doc/haskell-tasty-hslua/html/tasty-hslua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hslua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
